# Copyright (c) Twisted Matrix Laboratories.
# See LICENSE for details.

"""
Tests for L{twisted.cred}'s implementation of CRAM-MD5.
"""

from __future__ import division, absolute_import

from hmac import HMAC
from binascii import hexlify

from twisted.trial.unittest import TestCase
from twisted.cred.credentials import CramMD5Credentials
from twisted.cred.credentials import IUsernameHashedPassword



class CramMD5CredentialsTests(TestCase):
    """
    Tests for L{CramMD5Credentials}.
    """
    def test_idempotentChallenge(self):
        """
        The same L{CramMD5Credentials} will always provide the same challenge,
        no matter how many times it is called.
        """
        c = CramMD5Credentials()
        chal = c.getChallenge()
        self.assertEqual(chal, c.getChallenge())


    def test_interface(self):
        """
        L{CramMD5Credentials} implements the L{IUsernameHashedPassword}
        interface.
        """
        self.assertTrue(
            IUsernameHashedPassword.implementedBy(CramMD5Credentials))
